==> vod-api-model-1.0.2-sources.jar: com/valor/vod/api/model/linked/request/LinkedSyncReq.java <==
package com.valor.vod.api.model.linked.request;

import com.valor.vod.api.model.common.AbstractPrintable;
import com.valor.vod.api.model.common.request.IRequestQuery;
import com.valor.vod.api.model.linked.common.LinkedAcctDo;
import com.valor.vod.api.model.linked.common.LinkedChecksumDo;
import com.valor.vod.api.model.linked.common.LinkedItemDo;

import java.util.ArrayList;
import java.util.List;

/** Project : volor Description : Author : Frank Create Time : 2015/11/29 11:58 */
public class LinkedSyncReq extends AbstractPrintable implements IRequestQuery {
    protected LinkedAcctDo acct;
    protected List<LinkedItemDo> putList = new ArrayList<>();
    protected List<LinkedChecksumDo> delList = new ArrayList<>();
    private boolean delAll;

    public LinkedSyncReq() {}

    public LinkedAcctDo getAcct() {
        return acct;
    }

    public void setAcct(LinkedAcctDo acct) {
        this.acct = acct;
    }

    public boolean isDelAll() {
        return delAll;
    }

    public void setDelAll(boolean delAll) {
        this.delAll = delAll;
    }

    public List<LinkedItemDo> getPutList() {
        return putList;
    }

    public void setPutList(List<LinkedItemDo> putList) {
        this.putList = putList;
    }

    public List<LinkedChecksumDo> getDelList() {
        return delList;
    }

    public void setDelList(List<LinkedChecksumDo> delList) {
        this.delList = delList;
    }

    @Override
    public String toQueryString() {
        return null;
    }
}

==> vod-api-model-3.0.0-sources.jar: com/valor/vod/api/model/linked/request/LinkedSyncReq.java <==
package com.valor.vod.api.model.linked.request;

import com.valor.vod.api.model.common.AbstractPrintable;
import com.valor.vod.api.model.common.request.IRequestQuery;
import com.valor.vod.api.model.linked.common.LinkedAcctDo;
import com.valor.vod.api.model.linked.common.LinkedChecksumDo;
import com.valor.vod.api.model.linked.common.LinkedItemDo;

import java.util.ArrayList;
import java.util.List;

/**
 * Project     : volor
 * Description :
 * Author      : Frank
 * Create Time : 2015/11/29 11:58
 */
public class LinkedSyncReq extends AbstractPrintable implements IRequestQuery {
    protected LinkedAcctDo acct;
    protected List<LinkedItemDo> putList = new ArrayList<>();
    protected List<LinkedChecksumDo> delList = new ArrayList<>();
    private boolean delAll;

    public LinkedSyncReq() {

    }

    public LinkedAcctDo getAcct() {
        return acct;
    }

    public void setAcct(LinkedAcctDo acct) {
        this.acct = acct;
    }

    public boolean isDelAll() {
        return delAll;
    }

    public void setDelAll(boolean delAll) {
        this.delAll = delAll;
    }

    public List<LinkedItemDo> getPutList() {
        return putList;
    }

    public void setPutList(List<LinkedItemDo> putList) {
        this.putList = putList;
    }

    public List<LinkedChecksumDo> getDelList() {
        return delList;
    }

    public void setDelList(List<LinkedChecksumDo> delList) {
        this.delList = delList;
    }

    @Override
    public String toQueryString() {
        return null;
    }

}
